hx_articles: Articles

Description Usage Arguments Examples

Description

Return fake news matching query.

Usage

1
hx_articles(q, sort_by = c("recent", "relevant"))

Arguments

q

Keywords to search in Lucene query syntax is supported, e.g., +title:Trump. Available field names are title, meta, content, canonical_url and date_published. The field date_published is saved as text yyyy-mm-ddThh:mm:ss, you can use a termrangefilter on this field, e.g., the string 'pizzagate AND date_published:[2016-10-28 TO 2016-12-04]' will query documents with any fields contain pizzagate and the date_published is between 2016-10-28 to 2016-12-04.

sort_by

Choices are relevant recent. Specify how to sort the result, by the most relevant or recent

Examples

1
2
3
4
## Not run: 
articles <- hx_articles("pizzagate")

## End(Not run)

news-r/hoaxy documentation built on June 26, 2019, 8:08 p.m.