hx_edges: Edges

Description Usage Arguments Examples

Description

Return diffusion network (retweets, quotes, and optionally mentions). The direction of an edge indicates the flow of the claim. For a retweet, it goes from the original poster to the retweeter. For a mention, it goes from the account that is mentioning to the account that is mentioned.

Usage

1
hx_edges(ids, nodes_limit = 1000, include_user_mentions = FALSE)

Arguments

ids

A list or vector of article ids to query, see hx_articles.

nodes_limit

Network size limit by number of nodes. Default 1000. When nodes of network exceeds this parameter, a k-core algorithm is used to remove the least degree nodes and the associated edges.

include_user_mentions

Whether to return user mentions.

Examples

1
2
3
4
5
## Not run: 
articles <- hx_articles("pizzagate")
network <- hx_edges(articles$id[1:5])

## End(Not run)

news-r/hoaxy documentation built on June 26, 2019, 8:08 p.m.