hx_latest_articles: Top Articles

Description Usage Arguments Examples

Description

Return top 20 most active user for the last 30 days.

Usage

1
hx_latest_articles(past_hours = 2, domains = NULL)

Arguments

past_hours

Hours from "now" (Sys.time()), you are suggested to start this number from 2 as servers are not real time.

domains

Return articles restrained to these domains. Default is None, return all available articles. If fact_checking, return only fact checking articles. If claim, return only claim articles. If fake, return articles from sites marking as fake by our configuration. You can also input a domain list.

Examples

1
2
3
4
## Not run: 
hx_latest_articles()

## End(Not run)

news-r/hoaxy documentation built on June 26, 2019, 8:08 p.m.