hx_top_articles: Top Articles

Description Usage Arguments Examples

Description

Return top 20 most active user for the last 30 days.

Usage

1
2
hx_top_articles(upper_day = NULL, most_recent = FALSE,
  exclude_tags = NULL)

Arguments

upper_day

When calculating the most active users, we consider a 30 days window. The right bound controls the position of the window and it is called upper_day, e.g., if upper_day is set to 2016-12-01, then the window ranges between 2016-11-01 and 2016-12-01. Input format is yyyy-mm-dd, and the default value is the date of yesterday. Note that the endpoint does not accept any input more recent than the date of yesterday. Also currently the minimal upper_day value is 2016-12-12.

most_recent

When set to TRUE, return most recent available top spreaders, if there is no top spreaders for upper_day.

exclude_tags

Use double quote around excluded tags to make sure the URL encoding works on Mashape. This parameter controls the filtering of the returned results by excluded tags. The tags could be either in format of a list of strings, e.g., list("fake", "satire"). In the latter case, the first element in the tuple indicates the name of the source that tagged the website. Please refer to the Hoaxy FAQ for sources.

Examples

1
2
3
4
## Not run: 
hx_top_articles()

## End(Not run)

news-r/hoaxy documentation built on June 26, 2019, 8:08 p.m.