Description Usage Arguments Examples
Return diffusion network (retweets, quotes, and optionally mentions). The direction of an edge indicates the flow of the claim. For a retweet, it goes from the original poster to the retweeter. For a mention, it goes from the account that is mentioning to the account that is mentioned.
1 |
ids |
A list or vector of article ids to query, see |
nodes_limit |
Network size limit by number of nodes. Default 1000. When nodes of network exceeds this parameter, a k-core algorithm is used to remove the least degree nodes and the associated edges. |
include_user_mentions |
Whether to return user mentions. |
1 2 3 4 5 | ## Not run:
articles <- hx_articles("pizzagate")
network <- hx_edges(articles$id[1:5])
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.