Description Usage Arguments Examples
Return top 20 most active user for the last 30 days.
1 | hx_spreaders(upper_day = NULL, most_recent = FALSE)
|
upper_day |
When calculating the most active users, we consider a 30 days window.
The right bound controls the position of the window and it is called |
most_recent |
When set to |
1 2 3 4 | ## Not run:
hx_spreaders()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.