Description Usage Arguments Examples
Return top 20 most active user for the last 30 days.
1 2 | hx_top_articles(upper_day = NULL, most_recent = FALSE,
exclude_tags = NULL)
|
upper_day |
When calculating the most active users, we consider a 30 days window.
The right bound controls the position of the window and it is called |
most_recent |
When set to |
exclude_tags |
Use double quote around excluded tags to make sure the URL encoding works on Mashape.
This parameter controls the filtering of the returned results by excluded tags.
The tags could be either in format of a list of strings, e.g., |
1 2 3 4 | ## Not run:
hx_top_articles()
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.